==> jwinner-base-0.1.0-sources.jar: itez/plat/site/model/base/BaseChannel.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseChannel<M extends BaseChannel<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setCode(java.lang.String code) {
		set("code", code);
		return (M)this;
	}
	
	public java.lang.String getCode() {
		return getStr("code");
	}

	public M setIcon(java.lang.String icon) {
		set("icon", icon);
		return (M)this;
	}
	
	public java.lang.String getIcon() {
		return getStr("icon");
	}

	public M setPic(java.lang.String pic) {
		set("pic", pic);
		return (M)this;
	}
	
	public java.lang.String getPic() {
		return getStr("pic");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setContent(java.lang.String content) {
		set("content", content);
		return (M)this;
	}
	
	public java.lang.String getContent() {
		return getStr("content");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setChannelTemp(java.lang.String channelTemp) {
		set("channelTemp", channelTemp);
		return (M)this;
	}
	
	public java.lang.String getChannelTemp() {
		return getStr("channelTemp");
	}

	public M setContentTemp(java.lang.String contentTemp) {
		set("contentTemp", contentTemp);
		return (M)this;
	}
	
	public java.lang.String getContentTemp() {
		return getStr("contentTemp");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.1.7-sources.jar: itez/plat/site/model/base/BaseChannel.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseChannel<M extends BaseChannel<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setSubDomain(java.lang.String subDomain) {
		set("subDomain", subDomain);
		return (M)this;
	}
	
	public java.lang.String getSubDomain() {
		return getStr("subDomain");
	}

	public M setCode(java.lang.String code) {
		set("code", code);
		return (M)this;
	}
	
	public java.lang.String getCode() {
		return getStr("code");
	}

	public M setIcon(java.lang.String icon) {
		set("icon", icon);
		return (M)this;
	}
	
	public java.lang.String getIcon() {
		return getStr("icon");
	}

	public M setPic(java.lang.String pic) {
		set("pic", pic);
		return (M)this;
	}
	
	public java.lang.String getPic() {
		return getStr("pic");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setContent(java.lang.String content) {
		set("content", content);
		return (M)this;
	}
	
	public java.lang.String getContent() {
		return getStr("content");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setChannelTemp(java.lang.String channelTemp) {
		set("channelTemp", channelTemp);
		return (M)this;
	}
	
	public java.lang.String getChannelTemp() {
		return getStr("channelTemp");
	}

	public M setContentTemp(java.lang.String contentTemp) {
		set("contentTemp", contentTemp);
		return (M)this;
	}
	
	public java.lang.String getContentTemp() {
		return getStr("contentTemp");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
